import { invariant } from "ts-invariant";
import isArray from "lodash/isArray.js";
class ResultDataMethods {
    dataView;
    constructor(dataView) {
        this.dataView = dataView;
    }
    isEmpty() {
        return this.dataView.data.length === 0;
    }
    firstDimSize() {
        return this.dataView.totalCount[0];
    }
    secondDimSize() {
        return this.dataView.totalCount[1];
    }
    dataAt(index) {
        return this.dataView.data[index];
    }
    data() {
        return this.dataView.data;
    }
    singleDimData() {
        const d = this.dataView.data;
        if (d === null) {
            return [];
        }
        const e = d[0];
        invariant(!isArray(e), "trying to work with single-dim data while the underlying data view has two dims");
        return d;
    }
    twoDimData() {
        const d = this.dataView.data;
        if (d === null) {
            return [];
        }
        const e = d[0];
        if (e === null || !e) {
            return [];
        }
        return isArray(e) ? d : [d];
    }
    forecastTwoDimData() {
        const { prediction, low, high, loading } = this.dataView.forecast();
        if (prediction === null) {
            return [];
        }
        const e = prediction[0];
        if (!e) {
            return [];
        }
        return prediction.map((p, id) => p.map((_, ii) => ({
            prediction: prediction[id][ii],
            low: low[id][ii],
            high: high[id][ii],
            loading,
        })));
    }
    totals() {
        return this.dataView.totals;
    }
    rowTotals() {
        return this.dataView.totals?.[0];
    }
    columnTotals() {
        return this.dataView.totals?.[1];
    }
    totalOfTotals() {
        return this.dataView.totalTotals;
    }
    /**
     *
     * @returns - existance of totals for rows
     */
    hasRowTotals() {
        return this.dataView.totals?.[0] !== undefined && this.dataView.totals[0].length > 0;
    }
    /**
     *
     * @returns - existance of totals for columns
     */
    hasColumnTotals() {
        return this.dataView.totals?.[1] !== undefined && this.dataView.totals[1].length > 0;
    }
    /**
     *
     * @returns - existance of totals
     */
    hasTotals() {
        return this.dataView.totals !== undefined;
    }
}
export function newResultDataMethods(dataView) {
    return new ResultDataMethods(dataView);
}
//# sourceMappingURL=resultDataMethods.js.map